<?

/************************************************************************/
/* FlatNuke - Flat Text Based Content Management System                 */
/* ============================================                         */
/*                                                                      */
/* Copyright (c) 2003-2004 by Simone Vellei                             */
/* http://flatnuke.sourceforge.net                                      */
/*                                                                      */
/* This program is free software. You can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License.       */
/************************************************************************/


/**
 * File delle funzioni condivise tra il forum e il core di FlatNuke
 *
 * Questo file contiene le procedure di sistema necessarie al funzionamento
 * di FlatNuke e del suo forum.
 *
 * @package Funzioni_di_sistema
 *
 * @author Simone Vellei <simone_vellei@users.sourceforge.net>
 * @version 2.5.5
 * @copyright Copyright (c) 2003-2005
 * @license http://opensource.org/licenses/gpl-license.php GNU General Public License
 */


/**
 * Restituisce il codice di controllo codificato MD5 di un utente
 *
 * Restituisce il codice di controllo dell'utente passato come parametro,
 * mantenendo la codifica MD5.
 *
 * @author Simone Vellei <simone_vellei@users.sourceforge.net>
 *
 * @param string $user Nome assoluto del profilo utente da elaborare
 * @return string Codice di controllo codificato MD5 dell'utente
 */
function getpass($user)
{
	$fd = file("users/".$user.".php");
	$pass = str_replace("#", "", str_replace("\n", "", $fd[1]));
	return ($pass);
}


/**
 * Applica un semaforo ad un file
 *
 * Applica un semaforo al file passato come parametro, impedendo qualsiasi
 * azione fintanto che non sar spento con la chiave MD5 corretta.
 * NB: la gestione dei semafori deve essere supportata dal proprio webserver.
 *
 * @author Simone Vellei <simone_vellei@users.sourceforge.net>
 *
 * @param string $user Nome assoluto del file da bloccare
 * @return string ID del semaforo
 */
function lock($filename)
{
	/* uncomment this if your webserver
	// supports semaphores
	// get semaphore key
	$sem_key = md5($filename);
	// get semaphore identifier
	$sem_id = sem_get($sem_key, 1);
	// acquire semaphore lock
	sem_acquire($sem_id);
	// return sem_id
	return $sem_id;
	*/
}


/**
 * Rilascia un semaforo applicato ad un file
 *
 * Rilascia il semaforo con ID uguale a quello passato come parametro,
 * permettendo nuovamente l'accesso al relativo file.
 * NB: la gestione dei semafori deve essere supportata dal proprio webserver.
 *
 * @author Simone Vellei <simone_vellei@users.sourceforge.net>
 *
 * @param string $user ID del semaforo
 */
function unlock($sem_id)
{
	/* uncomment this if your webserver
	// supports semaphores
	// release semaphore lock
	sem_release($sem_id);
	*/
}


/**
 * Restituisce il codice di controllo decodificato MD5 di un utente
 *
 * Restituisce il codice di controllo dell'utente passato come parametro,
 * decodificandolo con algoritmo MD5.
 *
 * @author Simone Vellei <simone_vellei@users.sourceforge.net>
 *
 * @param string $user Nome assoluto del profilo utente da elaborare
 * @return string Codice di controllo decodificato MD5 dell'utente
 */
function getsecid($user){
	$fd=file("forum/users/".$user.".php");
	$pass=str_replace("#","",str_replace("\n","",$fd[1]));
	return (md5($user.$pass));
}


/**
 * Verifica il codice di controllo da FlatNuke
 *
 * Verifica che il codice di controllo immesso dall'utente e salvato nel cookie
 * corrisponda a quello del profilo dell'utente stesso.
 *
 * @author Simone Vellei <simone_vellei@users.sourceforge.net>
 *
 * @param string $user Nome assoluto del profilo utente da elaborare
 * @return boolean Vero o falso
 */
function versecid($user)
{
	$mysecid = $_COOKIE['secid'];
	if (getsecid($user) == $mysecid)
		return (TRUE);
	else
		return (FALSE);

}


/**
 * Verifica il codice di controllo dal forum
 *
 * Verifica che il codice di controllo immesso dall'utente e salvato nel cookie
 * corrisponda a quello del profilo dell'utente stesso.
 *
 * @author Simone Vellei <simone_vellei@users.sourceforge.net>
 *
 * @param string $user Nome assoluto del profilo utente da elaborare
 * @return boolean Vero o falso
 */
function versecid2($user)
{
	$mysecid = $_COOKIE['secid'];
	if (md5($user.getpass($user)) == $mysecid)
		return (TRUE);
	else
		return (FALSE);

}


/**
 * Mette un file in una stringa
 *
 * Trasforma il file passato come parametro in una stringa di testo.
 *
 * @author Simone Vellei <simone_vellei@users.sourceforge.net>
 *
 * @param string $filename Nome relativo alla root del file da elaborare
 * @return string Stringa con il contenuto del file
 */
function get_file($filename){

$fd = fopen ("$filename", "r");
	if($fd=="")
	die(_NONPUOI);
while (!feof ($fd)) {
$buffer = fgets($fd, 4096);
$string.=$buffer;
}
fclose ($fd);
return $string;
}


/**
 * Restituisce un elemento XML
 *
 * Restituisce un elemento XML da un file passato come parametro.
 *
 * @author Simone Vellei <simone_vellei@users.sourceforge.net>
 *
 * @param string $elem Nome dell'elemento XML da cercare
 * @param string $xml Nome del file XML da processare
 * @return string Stringa contenente il valore dell'elemento XML
 */
function get_xml_element($elem,$xml){

	$buff = ereg_replace(".*<".$elem.">","",$xml);
	$buff = ereg_replace("</".$elem.">.*","",$buff);
	return $buff;

}


/**
 * Restituisce l'array di un ramo di elementi XML
 *
 * Restituisce l'array di un ramo di elementi XML da un file passato come parametro.
 *
 * @author Simone Vellei <simone_vellei@users.sourceforge.net>
 *
 * @param string $elem Nome del ramo di elementi XML da cercare
 * @param string $xml Nome del file XML da processare
 * @return array Array contenente il ramo di elementi XML
 */
function get_xml_array($elem,$xml){

	$buff = explode("</".$elem.">",$xml);
	array_splice ($buff, count($buff)-1);
	return $buff;

}


/**
 * Restituisce il livello di un utente
 *
 * Restituisce il livello dell'utente passato come primo parametro; il secondo
 * parametro serve per gestire il riferimento alla cartella dove sono
 * presenti gli utenti, a seconda che la chiamata parta dall'homepage oppure
 * dal forum:
 *  - 0 per un utente registrato;
 *  - da 1 a 9 per un utente registrato di livello intermedio;
 *  - 10 per un utente amministratore.
 *
 * @author Simone Vellei <simone_vellei@users.sourceforge.net>
 *
 * @param string $admin Nome assoluto del profilo utente da elaborare
 * @param string $from Origine della chiamata ("home"/"forum")
 * @return string Livello dell'utente
 */
function getlevel($admin, $from){

// controlla implicitamente anche l'esistenza dell'account
// del nome passato, quindi anche la corrispondenza del cookie


if($from=="home"){
	if(!file_exists("forum/users/$admin.php"))
		return(-1);
	$fd=file("forum/users/$admin.php");
	$level=str_replace("#","",str_replace("\n","",$fd[9]));
	return($level);
}

	if($from=="forum"){
	if(!file_exists("users/$admin.php"))
		return(-1);
	$fd=file("users/$admin.php");
	$level=str_replace("#","",str_replace("\n","",$fd[9]));
	return($level);
	}
}
?>
